@@ -60,11 +60,12 @@ class SimplicialComplexTests(unittest.TestCase):
                                                                                                  p = p))
 
         # check sizes of boundary and basis matrices
+        # (assumes the default representation)
         ns = c.numberOfSimplicesOfOrder()
         for k in range(len(ns)):
-            self.assertEqual(c._bases[k].shape, (ns[0], ns[k]))
+            self.assertEqual(c._rep._bases[k].shape, (ns[0], ns[k]))
             if k > 0:
-                self.assertEqual(c._boundaries[k].shape, (ns[k - 1], ns[k]))
+                self.assertEqual(c._rep._boundaries[k].shape, (ns[k - 1], ns[k]))
 
 
     #---------- Construction ----------
@@ -263,8 +264,72 @@ class SimplicialComplexTests(unittest.TestCase):
         self.assertCountEqual(c.simplices(),
                               [ 1, 2, 3, 4, 5, 6,
                                 12, 13, 23, 45, 46, 56,
+
                                 123, 456 ])
 
+    def testCopyInto(self):
+        '''Test we can copy one complex into another.'''
+        c = SimplicialComplex()
+        c.addSimplex(id = 1)
+        c.addSimplex(id = 2)
+        c.addSimplex(id = 3)
+        c.addSimplex(id = 12, fs = [ 1, 2 ])
+        c.addSimplex(id = 13, fs = [ 1, 3 ])
+        c.addSimplex(id = 23, fs = [ 2, 3 ])
+        c.addSimplex(id = 123, fs = [ 12, 23, 13 ])
+
+        d = SimplicialComplex()
+        d.addSimplex(id = 4)
+        d.addSimplex(id = 5)
+        d.addSimplex(id = 6)
+        d.addSimplex(id = 45, fs = [ 4, 5 ])
+        d.addSimplex(id = 46, fs = [ 4, 6 ])
+        d.addSimplex(id = 56, fs = [ 5, 6 ])
+        d.addSimplex(id = 456, fs = [ 45, 46, 56 ])
+
+        d.copy(c)
+        self.assertCountEqual(c.simplices(),
+                              [ 1, 2, 3, 4, 5, 6,
+                                12, 13, 23, 45, 46, 56,
+                                123, 456 ])
+
+    def testCopyIndependentAttributes(self):
+        '''Test that copying simplex attributes are independent.'''
+        c = SimplicialComplex()
+        c.addSimplex(id=1, attr=dict(a=1, b='hello'))
+
+        d = c.copy()
+        d[1]['a'] = 2
+        self.assertEqual(d[1]['a'], 2)
+        self.assertEqual(d[1]['b'], 'hello')
+        self.assertEqual(c[1]['a'], 1)
+        self.assertEqual(c[1]['b'], 'hello')
+
+        del d[1]['a']
+        self.assertEqual(c[1]['a'], 1)
+        self.assertNotIn('a', d[1])
+
+    def testFailCopyInto(self):
+        '''Test we can't copy one complex into another if there are overlaps.'''
+        c = SimplicialComplex()
+        c.addSimplex(id = 1)
+        c.addSimplex(id = 2)
+        c.addSimplex(id = 3)
+        c.addSimplex(id = 12, fs = [ 1, 2 ])
+        c.addSimplex(id = 13, fs = [ 1, 3 ])
+        c.addSimplex(id = 23, fs = [ 2, 3 ])
+        c.addSimplex(id = 123, fs = [ 12, 23, 13 ])
+
+        d = SimplicialComplex()
+        d.addSimplex(id = 1)
+        d.addSimplex(id = 5)
+
+        with self.assertRaises(Exception):
+            d.copy(c)
+
+        # check c hasn't been changed
+        self.assertNotIn(5, c.simplices())
+
 
     # ---------- Relabelling ----------
 
@@ -400,7 +465,7 @@ class SimplicialComplexTests(unittest.TestCase):
         c.addSimplex(id = 123, fs = [ 12, 23, 13 ])
 
         ss = c.relabel(self.makeUniques(100))
-        self.assertCountEqual(ss, [ 101, 102, 103, 104, 105, 106, 107 ])
+        self.assertCountEqual(ss.values(), [ 101, 102, 103, 104, 105, 106, 107 ])
 
     def testRelabelFunction( self ):
         """Test relabelling with a function."""
@@ -414,10 +479,10 @@ class SimplicialComplexTests(unittest.TestCase):
         c.addSimplex(id = 123, fs = [ 12, 23, 13 ])
 
         ns = c.relabel(lambda s: s + 1000)
-        self.assertCountEqual(ns, [ 1001, 1002, 1003,
-                                    1012, 1013, 1023,
-                                    1123 ])
-        self.assertCountEqual(ns, c.simplices())
+        self.assertCountEqual(ns.values(), [ 1001, 1002, 1003,
+                                             1012, 1013, 1023,
+                                             1123 ])
+        self.assertCountEqual(ns.values(), c.simplices())
         self.assertCountEqual(c.faces(1123), [ 1012, 1013, 1023 ])
         self.assertCountEqual(c.faces(1012), [ 1001, 1002 ])
         self.assertCountEqual(c.faces(1013), [ 1001, 1003 ])
@@ -441,10 +506,10 @@ class SimplicialComplexTests(unittest.TestCase):
         for i in c.simplices():
             rename[i] = i + 1000
         ns = c.relabel(rename)
-        self.assertCountEqual(ns, [ 1001, 1002, 1003,
-                                    1012, 1013, 1023,
-                                    1123 ])
-        self.assertCountEqual(ns, c.simplices())
+        self.assertCountEqual(ns.values(), [ 1001, 1002, 1003,
+                                             1012, 1013, 1023,
+                                             1123 ])
+        self.assertCountEqual(ns.values(), c.simplices())
         self.assertCountEqual(c.faces(1123), [ 1012, 1013, 1023 ])
         self.assertCountEqual(c.faces(1012), [ 1001, 1002 ])
         self.assertCountEqual(c.faces(1013), [ 1001, 1003 ])
@@ -470,10 +535,8 @@ class SimplicialComplexTests(unittest.TestCase):
         del rename[1]
         del rename[123]
         ns = c.relabel(rename)
-        self.assertCountEqual(ns, [ 1, 1002, 1003,
-                                    1012, 1013, 1023,
-                                    123 ])
-        self.assertCountEqual(ns, c.simplices())
+        self.assertCountEqual(ns.values(), [ 1002, 1003,
+                                             1012, 1013, 1023 ])   # not 1 or 123, as they're not re-written
         self.assertCountEqual(c.faces(123), [ 1012, 1013, 1023 ])
         self.assertCountEqual(c.faces(1012), [ 1, 1002 ])
         self.assertCountEqual(c.faces(1013), [ 1, 1003 ])
@@ -500,6 +563,15 @@ class SimplicialComplexTests(unittest.TestCase):
         with self.assertRaises(ValueError):
             ns = c.relabel(rename)
 
+    def testRelabelDisjoint(self):
+        '''Test we can relabel a complex entirely disjointly from another.'''
+        c1 = ring(10)
+        c2 = ring(10)
+        self.assertTrue(len(set(c1.simplices()).intersection(set(c2.simplices()))) > 0)
+
+        c2.relabelDisjointFrom(c1)
+        self.assertTrue(len(set(c1.simplices()).intersection(set(c2.simplices()))) == 0)
+
     def testOrderViolation( self ):
         """Test that we throw an exception if we try to add a face with the wrong order."""
         c = SimplicialComplex()
@@ -1291,6 +1363,51 @@ class SimplicialComplexTests(unittest.TestCase):
         self._checkIntegrity(c)
 
 
+    # ---------- Predicates ----------
+
+    def testAllSimplices(self):
+        '''Test we can extract all simplices matching a predicate.'''
+        c = SimplicialComplex()
+        c.addSimplex(id = 1)
+        c.addSimplex(id = 2)
+        c.addSimplex(id = 3)
+        c.addSimplex(id = 12, fs = [ 1, 2 ])
+        c.addSimplex(id = 13, fs = [ 1, 3 ])
+        c.addSimplex(id = 23, fs = [ 2, 3 ])
+        c.addSimplex(id = 123, fs = [ 12, 23, 13 ])
+        c.addSimplex(id = 4)
+        c.addSimplex(id = 24, fs = [ 2, 4 ])
+        c.addSimplex(id = 34, fs = [ 3, 4 ])
+
+        sids = c.allSimplices(lambda c, s: s > 10)
+        self.assertCountEqual(sids, set([12, 13, 23, 123, 24, 34]))
+        self.assertEqual(sids[-1], 123)  # highest order last
+
+        sids = c.allSimplices(lambda c, s: s > 10, reverse=True)
+        self.assertCountEqual(sids, set([12, 13, 23, 123, 24, 34]))
+        self.assertEqual(sids[0], 123)  # highest order first
+
+    def testAnySimplex(self):
+        '''Test we can extract all simplices matching a predicate.'''
+        c = SimplicialComplex()
+        c.addSimplex(id = 1)
+        c.addSimplex(id = 2)
+        c.addSimplex(id = 3)
+        c.addSimplex(id = 12, fs = [ 1, 2 ])
+        c.addSimplex(id = 13, fs = [ 1, 3 ])
+        c.addSimplex(id = 23, fs = [ 2, 3 ])
+        c.addSimplex(id = 123, fs = [ 12, 23, 13 ])
+        c.addSimplex(id = 4)
+        c.addSimplex(id = 24, fs = [ 2, 4 ])
+        c.addSimplex(id = 34, fs = [ 3, 4 ])
+
+        s = c.anySimplex(lambda c, s: s > 10)
+        self.assertIn(s, set([12, 13, 23, 123, 24, 34]))
+
+        s = c.anySimplex(lambda c, s: s > 100)
+        self.assertEqual(s, 123)
+
+
     # ---------- Euler characteristic ----------
 
     def testEuler1hole( self ):
